@@ -7,7 +7,7 @@ Attean::API::Term - RDF Terms
 
 =head1 VERSION
 
-This document describes Attean::API::Term version 0.008
+This document describes Attean::API::Term version 0.009
 
 =head1 DESCRIPTION
 
@@ -43,7 +43,7 @@ Returns a string serialization of the term.
 
 =cut
 
-package Attean::API::Term 0.008 {
+package Attean::API::Term 0.009 {
 	use Moo::Role;
 	
 	with 'Attean::API::TermOrVariable', 'Attean::API::ResultOrTerm';
@@ -104,7 +104,7 @@ package Attean::API::Term 0.008 {
 	}
 }
 
-package Attean::API::Literal 0.008 {
+package Attean::API::Literal 0.009 {
 	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
@@ -202,6 +202,34 @@ package Attean::API::Literal 0.008 {
 		return %args;
 	}
 	
+	sub argument_compatible {
+		my $self	= shift;
+		my @terms	= @_;
+		
+		if (my $l = $self->language) {
+			foreach my $t (@terms) {
+				return 0 unless ($t->does('Attean::API::Literal'));
+				if ($t->language) {
+					return 0 unless (defined($t->language));
+					return 0 unless ($t->language eq $l);
+				} else {
+					return 0 unless ($t->datatype->value eq 'http://www.w3.org/2001/XMLSchema#string');
+				}
+			}
+			return 1;
+		} elsif ($self->datatype->value eq 'http://www.w3.org/2001/XMLSchema#string') {
+			foreach my $t (@terms) {
+				return 0 unless ($t->does('Attean::API::Literal'));
+				return 0 if ($t->language);
+				return 0 unless (blessed($t->datatype));
+				return 0 unless ($t->datatype->value eq 'http://www.w3.org/2001/XMLSchema#string');
+			}
+			return 1;
+		}
+		
+		return 0;
+	}
+	
 	sub _ntriples_string {
 		my $self	= shift;
 		my $str		= sprintf('"%s"', $self->__ntriples_string);
@@ -230,7 +258,7 @@ package Attean::API::Literal 0.008 {
 	};
 }
 
-package Attean::API::DateTimeLiteral 0.008 {
+package Attean::API::DateTimeLiteral 0.009 {
 	use Moo::Role;
 	use DateTime::Format::W3CDTF;
 	use namespace::clean;
@@ -241,12 +269,12 @@ package Attean::API::DateTimeLiteral 0.008 {
 	}
 }
 
-package Attean::API::CanonicalizingLiteral 0.008 {
+package Attean::API::CanonicalizingLiteral 0.009 {
 	use Moo::Role;
 	requires 'canonicalized_term';
 }
 
-package Attean::API::NumericLiteral 0.008 {
+package Attean::API::NumericLiteral 0.009 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed looks_like_number);
 	use namespace::clean;
@@ -437,7 +465,7 @@ package Attean::API::NumericLiteral 0.008 {
 	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
 }
 
-package Attean::API::Blank 0.008 {
+package Attean::API::Blank 0.009 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use namespace::clean;
@@ -453,7 +481,7 @@ package Attean::API::Blank 0.008 {
 	}
 }
 
-package Attean::API::IRI 0.008 {
+package Attean::API::IRI 0.009 {
 	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
