@@ -7,7 +7,7 @@ Attean::Triple - RDF Triples
 
 =head1 VERSION
 
-This document describes Attean::Triple version 0.007
+This document describes Attean::Triple version 0.009
 
 =head1 SYNOPSIS
 
@@ -38,8 +38,10 @@ This role consumes L<Attean::API::Triple>.
 
 =cut
 
-package Attean::TriplePattern 0.007 {
+package Attean::TriplePattern 0.009 {
 	use Moo;
+	use Scalar::Util qw(blessed);
+	use Attean::RDF;
 	use Attean::API::Binding;
 	
 	has 'subject'	=> (is => 'ro', required => 1);
@@ -48,17 +50,6 @@ package Attean::TriplePattern 0.007 {
 	
 	with 'Attean::API::TriplePattern';
 	
-	around BUILDARGS => sub {
-		my $orig 	= shift;
-		my $class	= shift;
-		if (scalar(@_) == 3) {
-			my %args;
-			@args{ $class->variables }	= @_;
-			return $class->$orig(%args);
-		}
-		return $class->$orig(@_);
-	};
-	
 	sub as_quadpattern {
 		my $self	= shift;
 		my $graph	= shift;
@@ -71,7 +62,7 @@ package Attean::TriplePattern 0.007 {
 	}
 }
 
-package Attean::Triple 0.007 {
+package Attean::Triple 0.009 {
 	use Moo;
 	use Attean::API::Binding;
 	
